@@ -17,11 +17,7 @@
 
 #include "settings.h"
 #include "settings-dialog.h"
-#if GTK_CHECK_VERSION(3, 0, 0)
-#include "settings-dialog-gtk3_ui.h"
-#else
 #include "settings-dialog_ui.h"
-#endif
 
 
 
@@ -111,7 +107,6 @@ xtm_settings_dialog_init (XtmSettingsDialog *dialog)
 	builder_bind_toggle_button (builder, "button-more-precision", dialog->settings, "more-precision");
 	builder_bind_toggle_button (builder, "button-prompt-terminate-task", dialog->settings, "prompt-terminate-task");
 	builder_bind_toggle_button (builder, "button-show-status-icon", dialog->settings, "show-status-icon");
-	builder_bind_toggle_button (builder, "button-show-memory-in-xbytes", dialog->settings, "show-memory-in-xbytes");
 	builder_bind_toggle_button (builder, "button-process-tree", dialog->settings, "process-tree");
 
 	{
@@ -122,21 +117,13 @@ xtm_settings_dialog_init (XtmSettingsDialog *dialog)
 		XtmToolbarStyle toolbar_style;
 
 		box = GTK_WIDGET (gtk_builder_get_object (builder, "hbox-toolbar-style"));
-#if GTK_CHECK_VERSION(2, 24, 1)
 		combobox = gtk_combo_box_text_new ();
-#else
-		combobox = gtk_combo_box_new_text ();
-#endif
 		gtk_box_pack_start (GTK_BOX (box), combobox, FALSE, FALSE, 0);
 		gtk_widget_show (combobox);
 
 		klass = g_type_class_ref (XTM_TYPE_TOOLBAR_STYLE);
 		for (n = 0; n < klass->n_values; ++n)
-#if GTK_CHECK_VERSION(2, 24, 1)
 			gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combobox), _(klass->values[n].value_nick));
-#else
-			gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), _(klass->values[n].value_nick));
-#endif
 		g_type_class_unref (klass);
 
 		g_object_get (dialog->settings, "toolbar-style", &toolbar_style, NULL);
@@ -173,9 +160,6 @@ xtm_settings_dialog_show (GtkWidget *widget)
 	g_return_if_fail (GTK_IS_WIDGET (XTM_SETTINGS_DIALOG (widget)->window));
 	gtk_widget_show (XTM_SETTINGS_DIALOG (widget)->window);
 	gtk_window_present (GTK_WINDOW (XTM_SETTINGS_DIALOG (widget)->window));
-#if !GTK_CHECK_VERSION(3, 0, 0)
-	GTK_WIDGET_SET_FLAGS (widget, GTK_VISIBLE);
-#endif
 }
 
 static void
@@ -188,9 +172,6 @@ xtm_settings_dialog_hide (GtkWidget *widget)
 	gtk_window_get_position (GTK_WINDOW (XTM_SETTINGS_DIALOG (widget)->window), &winx, &winy);
 	gtk_widget_hide (XTM_SETTINGS_DIALOG (widget)->window);
 	gtk_window_move (GTK_WINDOW (XTM_SETTINGS_DIALOG (widget)->window), winx, winy);
-#if !GTK_CHECK_VERSION(3, 0, 0)
-	GTK_WIDGET_UNSET_FLAGS (widget, (guint)GTK_VISIBLE);
-#endif
 }
 
 void
