@@ -60,6 +60,7 @@ struct _XtmTaskManager
 	gfloat			cpu_user;
 	gfloat			cpu_system;
 	guint64			memory_total;
+	guint64			memory_available; /* free + cache + buffers + an-OS-specific-value */
 	guint64			memory_free;
 	guint64			memory_cache;
 	guint64			memory_buffers;
@@ -343,13 +344,10 @@ task_list_find_for_pid (GArray *task_list, GPid pid, Task **task, guint *idx)
 static glong
 __current_timestamp (void)
 {
-	GTimeVal current_time;
-	g_get_current_time (&current_time);
-	return current_time.tv_sec;
+	gint64 tv = g_get_real_time ();
+	return tv / G_USEC_PER_SEC;
 }
 
-
-
 XtmTaskManager *
 xtm_task_manager_new (GtkTreeModel *model)
 {
@@ -370,10 +368,10 @@ xtm_task_manager_get_system_info (XtmTaskManager *manager, guint *num_processes,
 	*num_processes = manager->tasks->len;
 
 	/* Set memory and swap usage */
-	get_memory_usage (&manager->memory_total, &manager->memory_free, &manager->memory_cache, &manager->memory_buffers,
+	get_memory_usage (&manager->memory_total, &manager->memory_available, &manager->memory_free, &manager->memory_cache, &manager->memory_buffers,
 			&manager->swap_total, &manager->swap_free);
 
-	*memory_used = manager->memory_total - manager->memory_free - manager->memory_cache - manager->memory_buffers;
+	*memory_used = manager->memory_total - manager->memory_available;
 	*memory_total = manager->memory_total;
 	*swap_used = manager->swap_total - manager->swap_free;
 	*swap_total = manager->swap_total;
@@ -432,10 +430,12 @@ xtm_task_manager_update_model (XtmTaskManager *manager)
 		gtk_tree_model_get (manager->model, &cur_iter, XTM_PTV_COLUMN_CPU_STR, &cpu_str, XTM_PTV_COLUMN_TIMESTAMP, &old_timestamp, XTM_PTV_COLUMN_PID, &pid, -1);
 		found = (g_strcmp0 (cpu_str, "-") == 0);
 		g_free (cpu_str);
-		if (found && (timestamp - old_timestamp) > TIMESTAMP_DELTA)
+		if (found)
 		{
-			G_DEBUG_FMT ("Remove old task %d", pid);
-			model_remove_tree_iter (manager->model, &cur_iter);
+			if ((timestamp - old_timestamp) > TIMESTAMP_DELTA) {
+				G_DEBUG_FMT ("Remove old task %d", pid);
+				model_remove_tree_iter (manager->model, &cur_iter);
+			}
 			continue;
 		}
 
