@@ -39,9 +39,11 @@ struct _Task
 
 /**
  * OS specific implementation.
+ *
+ * memory_available = free + cache + buffers + an-OS-specific-value
  */
 
-gboolean	get_memory_usage	(guint64 *memory_total, guint64 *memory_free, guint64 *memory_cache, guint64 *memory_buffers, guint64 *swap_total, guint64 *swap_free);
+gboolean	get_memory_usage	(guint64 *memory_total, guint64 *memory_available, guint64 *memory_free, guint64 *memory_cache, guint64 *memory_buffers, guint64 *swap_total, guint64 *swap_free);
 gboolean	get_cpu_usage		(gushort *cpu_count, gfloat *cpu_user, gfloat *cpu_system);
 gboolean	get_task_list		(GArray *task_list);
 gboolean	pid_is_sleeping		(GPid pid);
